------------------------------------------------------------------------------
--
--  package Image_Processing (spec)
--
------------------------------------------------------------------------------
--  Update information:
--
--  1996.04.02 (Jacob Sparre Andersen)
--    Partially based on package Billedbehandling (spec) (1995.11.16)
--
--  1996.08.05 (Jacob Sparre Andersen)
--    Changed the formatting a little bit.
--
--  1996.09.10 (Jacob Sparre Andersen)
--    Label_Map is (not) packed.
--
--  1996.11.18 (Jacob Sparre Andersen)
--    Added "Expected_Number_of_Particles" to the argument list for procedure
--      Label_Particles and function Find_Particles.
--
--  1997.09.28-29 (Jacob Sparre Andersen)
--    Switched to access types where apropriate.
--
--  2001.02.10 (Jacob Sparre Andersen)
--    Added the exception Out_Of_Labels.
--
--  (Insert additional update information above this line.)
------------------------------------------------------------------------------

with Pixmaps;

generic

   type Pixel_Type is private;

   with package Image_Handling is new Pixmaps (Pixel_Type);

package Image_Processing is

   ---------------------------------------------------------------------------
   --  Exceptions:

   Out_Of_Labels : exception;

   ---------------------------------------------------------------------------
   --  subtype Image_Type:

   subtype Image_Type is Image_Handling.Pixmap_Type;

   subtype Image_Reference is Image_Handling.Pixmap_Reference;

   ---------------------------------------------------------------------------
   --  type Label_Type:

   type Label_Type is new Natural;

   ---------------------------------------------------------------------------
   --  type Label_Map:

   type Label_Map is
     array (Integer range <>, Integer range <>) of Label_Type;

   type Label_Map_Reference is access all Label_Map;

   ---------------------------------------------------------------------------
   --  procedure Label_Particles:
   --
   --  The image and the label map should have the same coordinate ranges.

   generic

      with function Is_A_Particle (Pixel : in Pixel_Type) return Boolean ;

   procedure Label_Particles
     (Image                        : in     Image_Reference;
      Labels                       : in     Label_Map_Reference;
      Number_of_Particles          :    out Integer;
      Expected_Number_of_Particles : in     Label_Type := Label_Type'Last);

   ---------------------------------------------------------------------------
   --  procedure Find_Particles:

   generic

      type Particle_Type is private;
      type Particle_List is array (Label_Type range <>) of Particle_Type;
      type Particle_List_Reference is access all Particle_List;

      Null_Particle : Particle_Type;

      with function Is_A_Particle (Pixel : in Pixel_Type) return Boolean ;

      with procedure Append (Particle : in out Particle_Type;
                             Pixel    : in     Pixel_Type;
                             X, Y     : in     Integer);

   function Find_Particles 
     (Image                        : in     Image_Reference;
      Expected_Number_of_Particles : in     Label_Type := Label_Type'Last) 
     return Particle_List_Reference;

   ---------------------------------------------------------------------------

end Image_Processing;
